==> tekton-model-triggers-v1alpha1-6.3.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerStatusFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.ConditionFluent;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1alpha1.AddressableFluent;
import java.lang.Integer;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface EventListenerStatusFluent<A extends EventListenerStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewV1alpha1Address(String hostname,String url);
  public EventListenerStatusFluent.V1alpha1AddressNested<A> withNewV1alpha1Address();
  public EventListenerStatusFluent.V1alpha1AddressNested<A> withNewAddressLike(Addressable item);
  public EventListenerStatusFluent.V1alpha1AddressNested<A> editV1alpha1Address();
  public EventListenerStatusFluent.V1alpha1AddressNested<A> editOrNewAddress();
  public EventListenerStatusFluent.V1alpha1AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public EventListenerStatusFluent.ConditionsNested<A> addNewCondition();
  public EventListenerStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public EventListenerStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public EventListenerStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public EventListenerStatusFluent.ConditionsNested<A> editFirstCondition();
  public EventListenerStatusFluent.ConditionsNested<A> editLastCondition();
  public EventListenerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConfiguration instead.
   * @return The buildable object.
   */
  @Deprecated
  public EventListenerConfig getConfiguration();
  public EventListenerConfig buildConfiguration();
  public A withConfiguration(EventListenerConfig configuration);
  public Boolean hasConfiguration();
  public A withNewConfiguration(String generatedName);
  public EventListenerStatusFluent.ConfigurationNested<A> withNewConfiguration();
  public EventListenerStatusFluent.ConfigurationNested<A> withNewConfigurationLike(EventListenerConfig item);
  public EventListenerStatusFluent.ConfigurationNested<A> editConfiguration();
  public EventListenerStatusFluent.ConfigurationNested<A> editOrNewConfiguration();
  public EventListenerStatusFluent.ConfigurationNested<A> editOrNewConfigurationLike(EventListenerConfig item);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface V1alpha1AddressNested<N> extends Nested<N>,AddressableFluent<EventListenerStatusFluent.V1alpha1AddressNested<N>>{
    public N and();
    public N endV1alpha1Address();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<EventListenerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface ConfigurationNested<N> extends Nested<N>,EventListenerConfigFluent<EventListenerStatusFluent.ConfigurationNested<N>>{
    public N and();
    public N endConfiguration();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerStatusFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.ConditionFluent;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1alpha1.AddressableFluent;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.tekton.triggers.internal.knative.pkg.apis.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface EventListenerStatusFluent<A extends EventListenerStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewV1alpha1Address(String hostname,String url);
  public EventListenerStatusFluent.V1alpha1AddressNested<A> withNewV1alpha1Address();
  public EventListenerStatusFluent.V1alpha1AddressNested<A> withNewAddressLike(Addressable item);
  public EventListenerStatusFluent.V1alpha1AddressNested<A> editV1alpha1Address();
  public EventListenerStatusFluent.V1alpha1AddressNested<A> editOrNewAddress();
  public EventListenerStatusFluent.V1alpha1AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToConditions(int index,Condition item);
  public A setToConditions(int index,Condition item);
  public A addToConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(int index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.tekton.triggers.internal.knative.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public EventListenerStatusFluent.ConditionsNested<A> addNewCondition();
  public EventListenerStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public EventListenerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
  public EventListenerStatusFluent.ConditionsNested<A> editCondition(int index);
  public EventListenerStatusFluent.ConditionsNested<A> editFirstCondition();
  public EventListenerStatusFluent.ConditionsNested<A> editLastCondition();
  public EventListenerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConfiguration instead.
   * @return The buildable object.
   */
  @Deprecated
  public EventListenerConfig getConfiguration();
  public EventListenerConfig buildConfiguration();
  public A withConfiguration(EventListenerConfig configuration);
  public Boolean hasConfiguration();
  public A withNewConfiguration(String generatedName);
  public EventListenerStatusFluent.ConfigurationNested<A> withNewConfiguration();
  public EventListenerStatusFluent.ConfigurationNested<A> withNewConfigurationLike(EventListenerConfig item);
  public EventListenerStatusFluent.ConfigurationNested<A> editConfiguration();
  public EventListenerStatusFluent.ConfigurationNested<A> editOrNewConfiguration();
  public EventListenerStatusFluent.ConfigurationNested<A> editOrNewConfigurationLike(EventListenerConfig item);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface V1alpha1AddressNested<N> extends Nested<N>,AddressableFluent<EventListenerStatusFluent.V1alpha1AddressNested<N>>{
    public N and();
    public N endV1alpha1Address();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<EventListenerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface ConfigurationNested<N> extends Nested<N>,EventListenerConfigFluent<EventListenerStatusFluent.ConfigurationNested<N>>{
    public N and();
    public N endConfiguration();
    
  }
  
}
